#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cryptonite-conduit
version:              0.2.2
visibility:           public
id:                   cryptonite-conduit-0.2.2-LWjKEoV8MKpE77HhZYAiUn
key:                  cryptonite-conduit-0.2.2-LWjKEoV8MKpE77HhZYAiUn
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/haskell-crypto/cryptonite-conduit
synopsis:             cryptonite conduit
description:
    Conduit bridge for cryptonite

    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.

category:             Cryptography, Conduit
abi:                  f81801075132d0cd02c68052f9527caf
exposed:              True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/cryptonite-conduit-0.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/cryptonite-conduit-0.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/cryptonite-conduit-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cryptonite-conduit
hs-libraries:         HScryptonite-conduit-0.2.2-LWjKEoV8MKpE77HhZYAiUn
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-4cc2yOSL2sy5iK6rZQd5vm
    conduit-extra-1.3.8-KyGJKsBlxeR6aLyGVSa94z
    cryptonite-0.30-KiHOALft5jFDbx6BJxMwmp exceptions-0.10.7
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    resourcet-1.2.6-Dhf0zTJRCL3LnKPExtEFW6 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-cryptonite-conduit/html/cryptonite-conduit.haddock

haddock-html:         /usr/share/doc/haskell-cryptonite-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

